//  Diffusion Client Library for iOS, OS X and tvOS
//
//  Copyright (c) 2016 Push Technology Ltd., All Rights Reserved.
//
//  Use is subject to license terms.
//
//  NOTICE: All information contained herein is, and remains the
//  property of Push Technology. The intellectual and technical
//  concepts contained herein are proprietary to Push Technology and
//  may be covered by U.S. and Foreign Patents, patents in process, and
//  are protected by trade secret or copyright law.

@import Foundation;

NS_ASSUME_NONNULL_BEGIN

/**
 @brief A reference to a handler registered for a particular topic path.
 
 A topic tree registration is provided whenever a handler with a server-side
 presence is registered.

 @since 5.7
 */
@interface PTDiffusionTopicTreeRegistration : NSObject

-(instancetype)init NS_UNAVAILABLE;

/**
 The topic path registered.

 @since 5.7
 */
@property(nonatomic, readonly) NSString* topicPath;

/**
 Request that the handler is unregistered from the server.

 If the handler has already been unregistered, calling this method has no effect.

 @since 5.7
 */
-(void)close;

@end

/**
 @brief Common protocol for delegates that establish a server side control presence for the
 client session at a particular branch of the topic tree.

 @since 5.7
 */
@protocol PTDiffusionTopicTreeRegistrationDelegate <NSObject>

@optional

/**
 Called if the handler is closed.
 
 No further calls will be made to this handler.

 @param registration The topic tree registration for which this delegate applies.

 @since 5.7
 */
-(void)diffusionTopicTreeRegistrationDidClose:(PTDiffusionTopicTreeRegistration *)registration;

/**
 Called in the event of a contextual error relating to this handler.

 No further calls will be made to this handler.

 @param registration The topic tree registration for which this delegate applies.
 
 @param error The failure reason.

 @since 5.7
 */
-(void)diffusionTopicTreeRegistration:(PTDiffusionTopicTreeRegistration *)registration
                     didFailWithError:(NSError *)error;

@end

NS_ASSUME_NONNULL_END
